@@ -31,7 +31,7 @@ class U_GP_Node_mv(MultivariateGaussian_Unobserved_Variational_Node):
         # Precompute terms (inverse covariance ant its determinant for each factor) to speed up computation
         # self.p_cov = self.P.params['cov']
         # self.p_cov_inv = np.array([s.linalg.inv(cov) for cov in tmp])
-        # self.p_cov_inv_diag = np.array([s.diag(c) for c in self.p_cov_inv])
+        # self.p_cov_inv_diag = np.array([np.diag(c) for c in self.p_cov_inv])
 
     def precompute(self, options):
         """ Method to precompute terms to speed up computation """
@@ -40,9 +40,9 @@ class U_GP_Node_mv(MultivariateGaussian_Unobserved_Variational_Node):
     def removeFactors(self, idx, axis=0):
         super().removeFactors(idx, axis)
         self.K = self.dim[1]
-        # self.p_cov = s.delete(self.p_cov, axis=0, obj=idx)
-        # self.p_cov_inv = s.delete(self.p_cov_inv, axis=0, obj=idx)
-        # self.p_cov_inv_diag = s.delete(self.p_cov_inv_diag, axis=0, obj=idx)
+        # self.p_cov = np.delete(self.p_cov, axis=0, obj=idx)
+        # self.p_cov_inv = np.delete(self.p_cov_inv, axis=0, obj=idx)
+        # self.p_cov_inv_diag = np.delete(self.p_cov_inv_diag, axis=0, obj=idx)
 
 
     def get_mini_batch(self):
@@ -110,9 +110,9 @@ class U_GP_Node_mv(MultivariateGaussian_Unobserved_Variational_Node):
         # Calculate variational updates - term for mean
         for k in range(K):
             bar = gpu_utils.array(np.zeros((N,)))
-            tmp_cp1 = gpu_utils.array(Z['E'][:, s.arange(K) != k])
+            tmp_cp1 = gpu_utils.array(Z['E'][:, np.arange(K) != k])
             for m in range(M):
-                tmp_cp2 = gpu_utils.array(W[m]["E"][:, s.arange(K) != k].T)
+                tmp_cp2 = gpu_utils.array(W[m]["E"][:, np.arange(K) != k].T)
 
                 bar_tmp1 = gpu_utils.array(W[m]["E"][:, k])
                 bar_tmp2 = gpu_utils.array(tau[m]) * (-gpu_utils.dot(tmp_cp1, tmp_cp2))
