@@ -1390,4 +1390,4 @@ def mofa(adata, groups_label: bool = None, use_raw: bool = False, use_layer: boo
                 else:
                     print("Saved MOFA embeddings in adata.obsm['X_mofa'] slot.")
     else:
-        print("Can not add embeddings and loadings to AnnData object since h5py is not installed.")
+        print("Can not add embeddings and loadings to AnnData object since h5py is not innp.alled.")
